@@ -1,5 +1,5 @@
 /**
- *  Time-stamp:  <2010-11-02 22:44:31 raskolnikov>
+ *  Time-stamp:  <2011-06-07 18:51:53 raskolnikov>
  *
  *  @file        exception.cpp
  *  @author      Juan Pedro Bolívar Puente <raskolnikov@es.gnu.org>
@@ -40,19 +40,24 @@ namespace base
 
 PSYNTH_DEFINE_ERROR (error);
 
-int error_base::level () const throw ()
+int default_error_level () throw ()
 {
     return log::error;
 }
 
+int error_base::level () const throw ()
+{
+    return default_error_level ();
+}
+
 const char* error_base::default_what () const throw ()
 {
     return "unknown error";
 }
 
-void error_base::log () const
+void exception::log () const
 {
-    logger::self  () (where (), level (), what ());
+    logger::self () (where (), level (), what ());
 }
 
 } /* namespace base */
