@@ -1,5 +1,5 @@
 /**
- *  Time-stamp:  <2011-03-09 17:47:57 raskolnikov>
+ *  Time-stamp:  <2011-07-03 13:02:47 raskolnikov>
  *
  *  @file        thread_async.cpp
  *  @author      Juan Pedro Bolívar Puente <raskolnikov@es.gnu.org>
@@ -28,8 +28,16 @@
  *
  */
 
+#define PSYNTH_MODULE_NAME "psynth.io.thread_async"
+
+#include "base/logger.hpp"
 #include "thread_async.hpp"
 
+#if __GTHREADS
+#include <pthread.h>
+#include <string.h>
+#endif
+
 namespace psynth
 {
 namespace io
@@ -46,14 +54,36 @@ void thread_async::stop ()
 {
     check_running ();
     set_state (async_state::idle);
-    _thread.join ();
+    if (_thread.joinable ())
+        _thread.join ();
 }
 
 void thread_async::run ()
 {
+    if (_realtime)
+        _request_rt ();
     while (state () == async_state::running)
         iterate ();
 }
 
+void thread_async::_request_rt ()
+{
+#if __GTHREADS
+    auto hdl = _thread.native_handle ();
+    sched_param p;
+    p.sched_priority = 1;
+    auto ret = pthread_setschedparam (hdl, SCHED_FIFO, &p);
+    
+#ifndef PSYNTH_NO_LOG_RT_REQUEST
+    if (ret)
+        PSYNTH_LOG << base::log::warning
+                   << "Could not set RT priority: "
+                   << strerror (ret);
+    else
+        PSYNTH_LOG << "Thread running with RT priority.";
+#endif
+#endif
+}
+
 } /* namespace io */
 } /* namespace psynth */
